pub struct WidgetDriverHandle { /* private fields */ }Available on crate feature
experimental-widgets only.Expand description
A handle that encapsulates the communication between a widget driver and the corresponding widget (inside a webview or iframe).
Implementations
Sourceimpl WidgetDriverHandle
impl WidgetDriverHandle
Sourcepub async fn recv(&self) -> Option<String>
pub async fn recv(&self) -> Option<String>
Receive a message from the widget driver.
The message must be passed on to the widget.
Returns None if the widget driver is no longer running.
Despite this method takes a shared reference to self with &self,
there is an inner lock around the receiver. They can be only one
receiver at a time. Be aware if recv is waiting in a loop for example.
This design addresses one particular need where WidgetDriverHandle
lives inside an Arc to be cloned and passed in 2 tasks: one calling
send, one calling recv. In that case, there is no conflict.